@@ -21,8 +21,7 @@ class RouteHandler(ExtensionHandlerMixin, JupyterHandler):
             
             if resource == 'version':
                 self.finish(json.dumps(_fetchVersion()))
-
-            if resource == 'config':
+            elif resource == 'config':
                 self.finish(json.dumps(self.config))
             else:
                 self.set_status(404)
